==> v1.3.8.zip: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/api/session/initsync/SyncStatusService.kt <==
/*
 * Copyright 2020 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.matrix.android.sdk.api.session.initsync

import androidx.lifecycle.LiveData

interface SyncStatusService {

    fun getSyncStatusLive(): LiveData<Status>

    sealed class Status {
        /**
         * For initial sync
         */
        abstract class InitialSyncStatus : Status()

        object Idle : InitialSyncStatus()
        data class Progressing(
                val initSyncStep: InitSyncStep,
                val percentProgress: Int = 0
        ) : InitialSyncStatus()

        /**
         * For incremental sync
         */
        abstract class IncrementalSyncStatus : Status()

        object IncrementalSyncIdle : IncrementalSyncStatus()
        data class IncrementalSyncParsing(
                val rooms: Int,
                val toDevice: Int
        ) : IncrementalSyncStatus()
        object IncrementalSyncError : IncrementalSyncStatus()
        object IncrementalSyncDone : IncrementalSyncStatus()
    }
}

==> v1.4.16.zip: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/api/session/initsync/SyncStatusService.kt <==
/*
 * Copyright 2020 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.matrix.android.sdk.api.session.initsync

import androidx.lifecycle.LiveData

interface SyncStatusService {

    fun getSyncStatusLive(): LiveData<Status>

    sealed class Status {
        /**
         * For initial sync.
         */
        abstract class InitialSyncStatus : Status()

        object Idle : InitialSyncStatus()
        data class InitialSyncProgressing(
                val initSyncStep: InitSyncStep,
                val percentProgress: Int = 0
        ) : InitialSyncStatus()

        /**
         * For incremental sync.
         */
        abstract class IncrementalSyncStatus : Status()

        object IncrementalSyncIdle : IncrementalSyncStatus()
        data class IncrementalSyncParsing(
                val rooms: Int,
                val toDevice: Int
        ) : IncrementalSyncStatus()

        object IncrementalSyncError : IncrementalSyncStatus()
        object IncrementalSyncDone : IncrementalSyncStatus()
    }
}
